==> simple_taxonomy_menu-2.0.1.tar.gz: simple_taxonomy_menu/src/Plugin/Block/SimpleTaxonomyMenuBlock.php <==
<?php

namespace Drupal\simple_taxonomy_menu\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Database\Connection;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Path\CurrentPathStack;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a menu block with taxonomy terms.
 *
 * @Block(
 *   id = "simple_taxonomy_menu_block",
 *   admin_label = @Translation("Simple Taxonomy Menu block"),
 *   category = @Translation("Simple Taxonomy Menu"),
 * )
 */
class SimpleTaxonomyMenuBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Returns the database service.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * Returns the current_route_match service.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * Returns the path.current service.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected $currentPath;

  /**
   * Returns the entity_type.manager service.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected $entityTypeManager;

  /**
   * Returns the logger.factory service.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected $logger;

  /**
   * Constructs an SimpleTaxonomyMenuBlock object.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, Connection $database, RouteMatchInterface $route_match, CurrentPathStack $current_path, EntityTypeManagerInterface $entity_type_manager, LoggerChannelInterface $logger) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->database = $database;
    $this->routeMatch = $route_match;
    $this->currentPath = $current_path;
    $this->entityTypeManager = $entity_type_manager;
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('database'),
      $container->get('current_route_match'),
      $container->get('path.current'),
      $container->get('entity_type.manager'),
      $container->get('logger.factory')->get('simple_taxonomy_menu')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'simple_taxonomy_menu_vid' => '',
      'simple_taxonomy_menu_before' => '',
      'simple_taxonomy_menu_after' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $list = [];
    /** @var \Drupal\taxonomy\VocabularyInterface $vocabulary */
    foreach ($this->entityTypeManager->getStorage('taxonomy_vocabulary')->loadMultiple() as $vocabulary) {
      $list[$vocabulary->id()] = $vocabulary->label();
    }

    $form['simple_taxonomy_menu_vid'] = [
      '#type' => 'select',
      '#title' => $this->t('Choose a taxonomy to create a menu out of'),
      '#default_value' => (string) $this->configuration['simple_taxonomy_menu_vid'],
      '#options' => $list,
      '#required' => TRUE,
    ];

    $form['simple_taxonomy_menu_before'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Menu items above'),
      '#description' => $this->t('Write down urls you want in the top of the menu.<br />
        Write down urls in as follow: url;title<br />
        Example external: http://www.google.com;Google<br />
        Example internal: node;Node list'),
      '#default_value' => $this->configuration['simple_taxonomy_menu_before'],
    ];

    $form['simple_taxonomy_menu_after'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Menu items below'),
      '#description' => $this->t('Write down urls you want in the bottom of the menu.<br />
        Write down urls in as follow: url;title<br />
        Example external: http://www.google.com;Google<br />
        Example internal: node;Node list'),
      '#default_value' => $this->configuration['simple_taxonomy_menu_after'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['simple_taxonomy_menu_vid'] = $values['simple_taxonomy_menu_vid'];
    $this->configuration['simple_taxonomy_menu_before'] = $values['simple_taxonomy_menu_before'];
    $this->configuration['simple_taxonomy_menu_after'] = $values['simple_taxonomy_menu_after'];

    parent::blockSubmit($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#markup' => $this->simpleTaxonomyMenuCreateMenu(),
      '#attached' => [
        'library' => ['simple_taxonomy_menu/block-menu'],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

  /**
   * Gets menu items and creates an html list.
   *
   * @return string
   *   Returns html string with menu in it.
   */
  public function simpleTaxonomyMenuCreateMenu() {
    if (empty($this->configuration['simple_taxonomy_menu_vid'])) {
      return '';
    }

    $vid = $this->configuration['simple_taxonomy_menu_vid'];
    $links_before = $this->configuration['simple_taxonomy_menu_before'];
    $links_after = $this->configuration['simple_taxonomy_menu_after'];

    $items = $this->simpleTaxonomyMenuLoadMenu($vid, $links_before, $links_after);

    return $this->simpleTaxonomyMenuCreatelist($items, '0');

  }

  /**
   * Create html menu list.
   *
   * @param array $items
   *   An array of items that needs to be in the menu.
   * @param int $parent
   *   The parent level of the menu items that needs to be proccesed.
   *
   * @return string
   *   Returns the menu with all menu item layers.
   */
  public function simpleTaxonomyMenuCreatelist(array $items, $parent) {
    $li = '';
    $first = TRUE;
    $last_tid = $this->simpleTaxonomyMenuLastItem($items, $parent);

    foreach ($items as $key => $item) {
      if (empty($item['term'])) {
        continue;
      }

      $term = $item['term'];
      if ($parent == '0' && is_string($term)) {
        $active_class = '';
        $class = '';

        if ($first == TRUE) {
          $class = 'first';
          $first = FALSE;
        }
        if ($this->currentPath->getPath() == $key) {
          $class .= ' active-trail';
          $active_class = 'active-trail active';
        }

        $url = '';
        try {
          $url = Url::fromUri($key)->toString();
        }
        catch (\Exception $e) {
          $this->logger->error($e->getMessage());
        }

        if ($url) {
          $li .= '<li class="menu__item is-leaf ' . $class . ' leaf" ><a title="' . $term . '" target="_blank" class="' . $active_class . '" href="' . $url . '">' . $term . '</a></li>' . "\n";
        }
      }
      else {
        if (!empty($term) && !empty($term->parents) && $term->parents[0] == $parent) {
          $active_class = '';
          $class = '';

          if ($first == TRUE) {
            $class = 'first';
            $first = FALSE;
          }
          elseif ($last_tid == $term->tid) {
            $class = 'last';
          }

          if ($item['active'] == '1') {
            $class .= ' active-trail';
            $active_class = 'active-trail active';
          }

          $links = $this->simpleTaxonomyMenuCreatelist($items, $term->tid);

          if ($links) {
            if ($item['open'] == '1') {
              $class .= ' expanded active-trail';
              $active_class = 'active-trail active';
            }
            else {
              $class .= ' collapsed';
            }

            $class .= ' expendable';
          }
          $li .= '<li class="menu__item is-leaf ' . $class . '" ><a title="' . $term->name . '" class="menu__link ' . $active_class . '" href="' . Url::fromUri('internal:/taxonomy/term/' . $term->tid)->toString() . '">' . $term->name . '</a>'
            . $links
            . '</li>' . "\n";
        }
      }
    }

    if (!empty($li)) {
      $html = '<ul id="category-menu-' . $parent . '" class="simple-taxonomy-menu menu clearfix">' . "\n" . '' . $li . '' . "\n" . '</ul>';

      return $html;
    }

    return '';
  }

  /**
   * Get the last item in the menu list.
   *
   * @param array $items
   *   List of menu items.
   * @param mixed $parent
   *   The parent level to show menu.
   *
   * @return int
   *   Returns tid of the last item in the menu.
   */
  public function simpleTaxonomyMenuLastItem(array $items, $parent) {
    $tid = NULL;

    foreach ($items as $item) {
      if (!empty($item['term'])) {
        $term = $item['term'];
        if (!empty($term->tid) && $term->parents[0] == $parent) {
          $tid = $term->tid;
        }
      }
    }

    return $tid;
  }

  /**
   * Load menu with all extra menu items.
   *
   * @param int $vid
   *   Taxonomy vocab id.
   * @param string $links_before
   *   A list of links before the menu.
   * @param string $links_after
   *   A list of links after the menu.
   *
   * @return array
   *   Returns an array of all menu items.
   */
  public function simpleTaxonomyMenuLoadMenu($vid, $links_before = '', $links_after = '') {
    $terms = $this->entityTypeManager
      ->getStorage('taxonomy_term')
      ->loadTree($vid, $parent = 0, $max_depth = NULL, $load_entities = FALSE);

    $node = $this->routeMatch->getParameter('node');
    $taxonomy = $this->routeMatch->getParameter('taxonomy_term');

    if (empty($_SESSION['simple_taxonomy_menu_active'])
      || (empty($node) && empty($taxonomy))) {
      $_SESSION['simple_taxonomy_menu_active'] = NULL;
    }

    // If user is viewing node we need to check if we still got a path.
    if ($node) {
      $query = $this->database->select('taxonomy_index', 'ti');
      $query->leftJoin('taxonomy_term_data', 'ttd', 'ti.tid = ttd.tid');
      $query->fields('ti', ['tid']);
      $query->condition('ti.nid', (int) $node->id());
      $query->condition('ttd.vid', $vid);
      $results = $query->execute()->fetchCol();

      // Check if the active term is also present in the currently viewed node.
      if (empty($_SESSION['simple_taxonomy_menu_active']) || empty($results[$_SESSION['simple_taxonomy_menu_active']])) {
        $_SESSION['simple_taxonomy_menu_active'] = !empty($results) ? reset($results) : NULL;
      }
    }

    $items = [];
    $ar_list_before = explode(PHP_EOL, $links_before);
    foreach ($ar_list_before as $link_string) {
      if (!empty($link_string)) {
        $ar_link_before = explode(';', $link_string);
        $items[$ar_link_before[0]]['term'] = trim($ar_link_before[1]);
      }
    }

    foreach ($terms as $term) {
      $items[$term->tid]['term'] = $term;
      $items[$term->tid]['active'] = 0;
      $items[$term->tid]['open'] = 0;

      if ($taxonomy) {
        if ($taxonomy->id() == $term->tid) {
          $items[$term->tid]['active'] = 1;
          $_SESSION['simple_taxonomy_menu_active'] = $term->tid;
        }
      }
      elseif ($node) {
        if (!empty($_SESSION['simple_taxonomy_menu_active']) && $_SESSION['simple_taxonomy_menu_active'] == $term->tid) {
          $items[$term->tid]['active'] = 1;
        }
      }
    }

    $ar_list_after = explode(PHP_EOL, $links_after);
    foreach ($ar_list_after as $link_string) {
      if (!empty($link_string)) {
        $ar_link_after = explode(';', $link_string);
        $items[$ar_link_after[0]]['term'] = trim($ar_link_after[1]);
      }
    }

    $items = $this->simpleTaxonomyMenuOpenParent($items, $_SESSION['simple_taxonomy_menu_active']);

    return $items;
  }

  /**
   * Set the active parents.
   *
   * @param array $items
   *   Menu list to ge through.
   * @param int $tid
   *   Term id to calculate the active path.
   *
   * @return array
   *   Returns the menu array with terms set to open.
   */
  public function simpleTaxonomyMenuOpenParent(array $items, $tid) {
    $items[$tid]['open'] = 1;

    if (!empty($items[$tid]['term']->parents) && $items[$tid]['term']->parents[0] != '0' && !empty($items[$tid]['term']->parents[0])) {
      $items = $this->simpleTaxonomyMenuOpenParent($items, $items[$tid]['term']->parents[0]);
    }

    return $items;
  }

}

==> simple_taxonomy_menu-2.1.0.tar.gz: simple_taxonomy_menu/src/Plugin/Block/SimpleTaxonomyMenuBlock.php <==
<?php

namespace Drupal\simple_taxonomy_menu\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Database\Connection;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Path\CurrentPathStack;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a menu block with taxonomy terms.
 *
 * @Block(
 *   id = "simple_taxonomy_menu_block",
 *   admin_label = @Translation("Simple Taxonomy Menu block"),
 *   category = @Translation("Simple Taxonomy Menu"),
 * )
 */
class SimpleTaxonomyMenuBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Returns the database service.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * Returns the current_route_match service.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * Returns the path.current service.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected $currentPath;

  /**
   * Returns the entity_type.manager service.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected $entityTypeManager;

  /**
   * Constructs an SimpleTaxonomyMenuBlock object.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, Connection $database, RouteMatchInterface $route_match, CurrentPathStack $current_path, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->database = $database;
    $this->routeMatch = $route_match;
    $this->currentPath = $current_path;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('database'),
      $container->get('current_route_match'),
      $container->get('path.current'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'simple_taxonomy_menu_vid' => '',
      'simple_taxonomy_menu_before' => '',
      'simple_taxonomy_menu_after' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $list = [];
    /** @var \Drupal\taxonomy\VocabularyInterface $vocabulary */
    foreach ($this->entityTypeManager->getStorage('taxonomy_vocabulary')->loadMultiple() as $vocabulary) {
      $list[$vocabulary->id()] = $vocabulary->label();
    }

    $form['simple_taxonomy_menu_vid'] = [
      '#type' => 'select',
      '#title' => $this->t('Choose a taxonomy to create a menu out of'),
      '#default_value' => (string) $this->configuration['simple_taxonomy_menu_vid'],
      '#options' => $list,
      '#required' => TRUE,
    ];

    $form['simple_taxonomy_menu_before'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Menu items above'),
      '#description' => $this->t('Write down urls you want in the top of the menu.<br />
        Write down urls in as follow: url;title<br />
        Example external: http://www.google.com;Google<br />
        Example internal: node;Node list'),
      '#default_value' => $this->configuration['simple_taxonomy_menu_before'],
    ];

    $form['simple_taxonomy_menu_after'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Menu items below'),
      '#description' => $this->t('Write down urls you want in the bottom of the menu.<br />
        Write down urls in as follow: url;title<br />
        Example external: http://www.google.com;Google<br />
        Example internal: node;Node list'),
      '#default_value' => $this->configuration['simple_taxonomy_menu_after'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['simple_taxonomy_menu_vid'] = $values['simple_taxonomy_menu_vid'];
    $this->configuration['simple_taxonomy_menu_before'] = $values['simple_taxonomy_menu_before'];
    $this->configuration['simple_taxonomy_menu_after'] = $values['simple_taxonomy_menu_after'];

    parent::blockSubmit($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#markup' => $this->simpleTaxonomyMenuCreateMenu(),
      '#attached' => [
        'library' => ['simple_taxonomy_menu/block-menu'],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

  /**
   * Gets menu items and creates an html list.
   *
   * @return string
   *   Returns html string with menu in it.
   */
  public function simpleTaxonomyMenuCreateMenu() {
    if (empty($this->configuration['simple_taxonomy_menu_vid'])) {
      return '';
    }

    $vid = $this->configuration['simple_taxonomy_menu_vid'];
    $links_before = $this->configuration['simple_taxonomy_menu_before'];
    $links_after = $this->configuration['simple_taxonomy_menu_after'];

    $items = $this->simpleTaxonomyMenuLoadMenu($vid, $links_before, $links_after);

    return $this->simpleTaxonomyMenuCreatelist($items, '0');

  }

  /**
   * Create html menu list.
   *
   * @param array $items
   *   An array of items that needs to be in the menu.
   * @param int $parent
   *   The parent level of the menu items that needs to be proccesed.
   *
   * @return string
   *   Returns the menu with all menu item layers.
   */
  public function simpleTaxonomyMenuCreatelist(array $items, $parent) {
    $li = '';
    $first = TRUE;
    $last_tid = $this->simpleTaxonomyMenuLastItem($items, $parent);

    foreach ($items as $key => $item) {
      if (empty($item['term'])) {
        continue;
      }

      $term = $item['term'];
      if ($parent == '0' && is_string($term)) {
        $active_class = '';
        $class = '';

        if ($first == TRUE) {
          $class = 'first';
          $first = FALSE;
        }
        if ($this->currentPath->getPath() == $key) {
          $class .= ' active-trail';
          $active_class = 'active-trail active';
        }
        $li .= '<li class="menu__item is-leaf ' . $class . ' leaf" ><a title="menu__link ' . $term . '" class="' . $active_class . '" href="' . Url::fromUri($key)->toString() . '">' . $term . '</a></li>' . "\n";
      }
      else {
        if (!empty($term) && !empty($term->parents) && $term->parents[0] == $parent) {
          $active_class = '';
          $class = '';

          if ($first == TRUE) {
            $class = 'first';
            $first = FALSE;
          }
          elseif ($last_tid == $term->tid) {
            $class = 'last';
          }

          if ($item['active'] == '1') {
            $class .= ' active-trail';
            $active_class = 'active-trail active';
          }

          $links = $this->simpleTaxonomyMenuCreatelist($items, $term->tid);

          if ($links) {
            if ($item['open'] == '1') {
              $class .= ' expanded active-trail';
              $active_class = 'active-trail active';
            }
            else {
              $class .= ' collapsed';
            }

            $class .= ' expendable';
          }
          $li .= '<li class="menu__item is-leaf ' . $class . '" ><a title="' . $term->name . '" class="menu__link ' . $active_class . '" href="' . Url::fromUri('internal:/taxonomy/term/' . $term->tid)->toString() . '">' . $term->name . '</a>'
            . $links
            . '</li>' . "\n";
        }
      }
    }

    if (!empty($li)) {
      $html = '<ul id="category-menu-' . $parent . '" class="simple-taxonomy-menu menu clearfix">' . "\n" . '' . $li . '' . "\n" . '</ul>';
      return $html;
    }
    else {
      return '';
    }
  }

  /**
   * Get the last item in the menu list.
   *
   * @param array $items
   *   List of menu items.
   * @param mixed $parent
   *   The parent level to show menu.
   *
   * @return int
   *   Returns tid of the last item in the menu.
   */
  public function simpleTaxonomyMenuLastItem(array $items, $parent) {
    $tid = NULL;

    foreach ($items as $item) {
      if (!empty($item['term'])) {
        $term = $item['term'];
        if (!empty($term->tid) && $term->parents[0] == $parent) {
          $tid = $term->tid;
        }
      }
    }

    return $tid;
  }

  /**
   * Load menu with all extra menu items.
   *
   * @param int $vid
   *   Taxonomy vocab id.
   * @param string $links_before
   *   A list of links before the menu.
   * @param string $links_after
   *   A list of links after the menu.
   *
   * @return array
   *   Returns an array of all menu items.
   */
  public function simpleTaxonomyMenuLoadMenu($vid, $links_before = '', $links_after = '') {
    $terms = $this->entityTypeManager
      ->getStorage('taxonomy_term')
      ->loadTree($vid, $parent = 0, $max_depth = NULL, $load_entities = FALSE);

    $node = $this->routeMatch->getParameter('node');
    $taxonomy = $this->routeMatch->getParameter('taxonomy_term');

    if (empty($_SESSION['simple_taxonomy_menu_active'])
      || (empty($node) && empty($taxonomy))) {
      $_SESSION['simple_taxonomy_menu_active'] = NULL;
    }

    // If user is viewing node we need to check if we still got a path.
    if ($node) {
      $query = $this->database->select('taxonomy_index', 'ti');
      $query->leftJoin('taxonomy_term_data', 'ttd', 'ti.tid = ttd.tid');
      $query->fields('ti', ['tid']);
      $query->condition('ti.nid', (int) $node->id());
      $query->condition('ttd.vid', $vid);
      $results = $query->execute()->fetchCol();

      // Check if the active term is also present in the currently viewed node.
      if (empty($_SESSION['simple_taxonomy_menu_active']) || empty($results[$_SESSION['simple_taxonomy_menu_active']])) {
        $_SESSION['simple_taxonomy_menu_active'] = !empty($results) ? reset($results) : NULL;
      }
    }

    $items = [];
    $ar_list_before = explode(PHP_EOL, $links_before);
    foreach ($ar_list_before as $link_string) {
      if (!empty($link_string)) {
        $ar_link_before = explode(';', $link_string);
        $items[$ar_link_before[0]]['term'] = trim($ar_link_before[1]);
      }
    }

    foreach ($terms as $term) {
      $items[$term->tid]['term'] = $term;
      $items[$term->tid]['active'] = 0;
      $items[$term->tid]['open'] = 0;

      if ($taxonomy) {
        if ($taxonomy->id() == $term->tid) {
          $items[$term->tid]['active'] = 1;
          $_SESSION['simple_taxonomy_menu_active'] = $term->tid;
        }
      }
      elseif ($node) {
        if (!empty($_SESSION['simple_taxonomy_menu_active']) && $_SESSION['simple_taxonomy_menu_active'] == $term->tid) {
          $items[$term->tid]['active'] = 1;
        }
      }
    }

    $ar_list_after = explode(PHP_EOL, $links_after);
    foreach ($ar_list_after as $link_string) {
      if (!empty($link_string)) {
        $ar_link_after = explode(';', $link_string);
        $items[$ar_link_after[0]]['term'] = trim($ar_link_after[1]);
      }
    }

    $items = $this->simpleTaxonomyMenuOpenParent($items, $_SESSION['simple_taxonomy_menu_active']);

    return $items;
  }

  /**
   * Set the active parents.
   *
   * @param array $items
   *   Menu list to ge through.
   * @param int $tid
   *   Term id to calculate the active path.
   *
   * @return array
   *   Returns the menu array with terms set to open.
   */
  public function simpleTaxonomyMenuOpenParent(array $items, $tid) {
    $items[$tid]['open'] = 1;

    if (!empty($items[$tid]['term']->parents) && $items[$tid]['term']->parents[0] != '0' && !empty($items[$tid]['term']->parents[0])) {
      $items = $this->simpleTaxonomyMenuOpenParent($items, $items[$tid]['term']->parents[0]);
    }

    return $items;
  }

}
